@@ -26,7 +26,7 @@ import hypothesis.internal.conjecture.utils as cu
 from hypothesis import Verbosity
 from hypothesis._settings import note_deprecation
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import hrange, integer_types, text_type
+from hypothesis.internal.compat import hrange, integer_types
 from hypothesis.internal.coverage import check_function
 from hypothesis.internal.reflection import proxies
 from hypothesis.internal.validation import check_type, check_valid_interval
@@ -636,9 +636,7 @@ def array_dtypes(
     """Return a strategy for generating array (compound) dtypes, with members
     drawn from the given subtype strategy."""
     order_check("size", 0, min_size, max_size)
-    native_strings = st.text()  # type: SearchStrategy[Any]
-    if text_type is not str:  # pragma: no cover
-        native_strings = st.binary()
+    native_strings = st.from_type(str).filter(bool)  # See issue #1798 re: filter!
     elements = st.tuples(native_strings, subtype_strategy)
     if allow_subarrays:
         elements |= st.tuples(
